<?php
/**                  
* Includes functions for bringing multiple plugins into a single schedule and
* automation system. A goal is balance within WordPress and another goal is 
* 100% user control over schedule and automation. 
* 
* The WebTechGlobal automation class is intended to be global within WordPress.
* More then one plugin may use the automation class but only one will run it.
* All active plugins using the automation class will be included in the systems
* ability to decide which action should be done. There is a cycle which ensures
* all plugins get their turn, all actions within the plugin gets a turn and
* WordPress is not overworked by too many plugins running on automation.
* 
* This DOES NOT use CRON! We use CRON for very manual and specific firing of
* individual functions. This system has it's own settings for permitted days,
* hours and frequency of events. These settings are global as of September 2015
* so that a growing number of WebTechGlobal plugins in a single blog, which use
* the automation class, do not over-work WP. 
* 
* SUGGESTED USE
* 
* 1. This class should never be edited. Copy it and use it for another purpose.
* 2. Create class-schedule.php in each package and THAT class will use this one. 
* 
* @package WebTechGlobal WordPress Plugins
* @author Ryan Bayne   
* @version 1.1
*/

// load in WordPress only
defined( 'ABSPATH' ) || die( 'No direct script access allowed!' );

    /*
       This new class will be developed slowly to avoid upsetting the current
       automation in this plugin and may not be a lot of use
       until well into 2016. 
    */
    
/**
* @todo create DB tables: one for registering packages, one for actions
*/
class WEBTECHGLOBAL_Automation{
    public $autoopt = array();
    
    public function __construct() {
        self::set_automation_option();// populates $this->$autoopt    
    }
    
    /**
    * Register a plugin to join automation by adding its registry
    * information to a WP option entry shared by all WTG plugins.
    * 
    * 1. register_for_automation_part2() is in class-schedule.php and is where
    * configuration is set for the plugin.
    * 
    * 2. register_for_automation_part1 should be placed in
    * 
    * @author Ryan R. Bayne
    * @package WebTechGlobal WordPress Plugins
    * @version 1.2
    * 
    * @param string $package_name slug i.e. csv2post or easy-csv-importer
    * @param array $package_atts
    * @param array $actions_array
    * 
    * @todo continue from here by entering data into tables
    */
    public function register_for_automation_part3( $package_atts, $actions_array ) {
        // enter package into wp_webtechglobal_packages table
        // enter actions into wp_webtechglobal_actions table
    }
    
    /**
    * Get the global automation option.
    * 
    * This option will be an array that includes the schedule data currently
    * unique to each plugin but to become global. The schedule settings will
    * be offered as a method to strictly control MOST if not all automation 
    * in the blog i.e. the user may want no automation at peak times and the
    * current settings will easily allow that to be achieved. The user will not
    * need to configure every plugin individually.
    * 
    * Individual package automation is to be controlled using CRON as a way to
    * introduce proper WP CRON usage and firing of specific functions with 
    * clear interfaces to manage this.
    * 
    * @author Ryan R. Bayne
    * @package WebTechGlobal WordPress Plugins
    * @version 1.0
    */
    public function set_automation_option() {
        // get the automation array
        $this->autoopt = get_option( 'webtechglobal_automation' );
        
        // set automation array if required
        if( !$this->autoopt ) {
            $this->autoopt = array();        
        }        
    }

    /**
    * Update main automation option.
    * 
    * @author Ryan R. Bayne
    * @package WebTechGlobal WordPress Plugins
    * @version 1.0
    */
    public function update_automation_option() {
        update_option( 'webtechglobal_automation', $this->auto_opt );
    }  
}
?>
